@@ -251,7 +251,7 @@ def fetch_series_by_api_link(
         # Store series dimensions information for future use
         series_dims_by_dataset_code[complete_dataset_code][series_infos["series"]["series_code"]] = series_infos[
             "series"
-        ]["dimensions"]
+        ].get("dimensions", {})
 
     if len(series_list) == 0:
         return pd.DataFrame()
@@ -285,7 +285,7 @@ def fetch_series_by_api_link(
             }
         # Add dimensions values labels to current series
         if "dimensions_values_labels" in dataset_dimensions:
-            for dimension_code in series["dimensions"]:
+            for dimension_code in series.get("dimensions", {}):
                 dimension_label = dataset_dimensions_labels[dimension_code]
                 dimension_value_code = series_dims_by_dataset_code[complete_dataset_code][series["series_code"]][
                     dimension_code
